@@ -20,7 +20,7 @@
         } else { 
 #            resList <- compute.delta.method(vcMat, expression(b1/b2), est, c("b1", "b2"), print = FALSE)
             
-            derivVec <- c(1 / est[2], -est[1] / est[2])           
+            derivVec <- c(1 / est[2], -est[1] / (est[2]^2))           
             estVal <- est[1] / est[2]
         }
     } else {
@@ -29,7 +29,7 @@
         derivVec <- c(1, -1)
         estVal <- est[1] - est[2]
     }
-    resList <- list(estimate = estVal, se = as.numeric(derivVec %*% vcMat %*% derivVec))            
+    resList <- list(estimate = estVal, se = sqrt(as.numeric(derivVec %*% vcMat %*% derivVec)))            
     colNames <- c("Estimate", "Std. Error")    
     
     edMat <- matrix(c(resList$estimate, resList$se), nrow = 1)
